@@ -25,5 +25,7 @@ type Listers struct {
 	ImageConfigs        configlisters.ImageLister
 	ClusterOperators    configlisters.ClusterOperatorLister
 	RegistryConfigs     regoplisters.ConfigLister
-	InstallerSecrets    kcorelisters.SecretNamespaceLister
+	InstallerConfigMaps kcorelisters.ConfigMapNamespaceLister
+	ProxyConfigs        configlisters.ProxyLister
+	Infrastructures     configlisters.InfrastructureLister
 }
